@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 # All Rights Reserved.
 #
@@ -31,4 +29,5 @@ class BackwardsCompatConfig(base.BaseConfig):
         packaging.append_text_list(
             self.config, 'tests_require',
             packaging.parse_requirements(
-                packaging.TEST_REQUIREMENTS_FILES))
+                packaging.TEST_REQUIREMENTS_FILES,
+                strip_markers=True))
